@@ -41,8 +41,7 @@ class ProcessControl : public QObject
      * @li StopOnCrash    - The application won't be restarted.
      * @li RestartOnCrash - The application is restarted with the same arguments.
      */
-    enum CrashPolicy
-    {
+    enum CrashPolicy {
       StopOnCrash,
       RestartOnCrash
     };
@@ -65,6 +64,11 @@ class ProcessControl : public QObject
     void start( const QString &application, const QStringList &arguments = QStringList(),
                 CrashPolicy policy = RestartOnCrash );
 
+    /**
+     * Starts the process with the previously set application and arguments.
+     */
+    void start();
+
     /**
      * Stops the currently running application.
      */
@@ -75,6 +79,23 @@ class ProcessControl : public QObject
      */
     void setCrashPolicy( CrashPolicy policy );
 
+    /**
+     * Restart the application the next time it exits normally.
+     */
+    void restartOnceWhenFinished() { mRestartOnceOnExit = true; }
+
+    /**
+     * Returns true if the process is currently running.
+     */
+    bool isRunning() const;
+
+    /**
+     * Sets the time (in msecs) we wait for the process to shut down before we send terminate/kill signals.
+     * Default is 1 second.
+     * Note that it is your responsiblility to ask the process to quit, otherwise this is just
+     * pointless waiting.
+     */
+    void setShutdownTimeout( int msecs );
 
   Q_SIGNALS:
     /**
@@ -85,6 +106,11 @@ class ProcessControl : public QObject
      */
     void processErrorMessages( const QString &errorMsg );
 
+    /**
+     * This signal is emitted when the server is restarted after a crash.
+     */
+    void restarted();
+
     /**
      * Emitted if the process could not be started since it terminated
      * too often.
@@ -94,19 +120,17 @@ class ProcessControl : public QObject
   private Q_SLOTS:
     void slotError( QProcess::ProcessError );
     void slotFinished( int, QProcess::ExitStatus );
-    void slotErrorMessages();
-    void slotStdoutMessages();
     void resetCrashCount();
 
   private:
-    void start();
-
     QProcess mProcess;
     QString mApplication;
     QStringList mArguments;
     CrashPolicy mPolicy;
     bool mFailedToStart;
     int mCrashCount;
+    bool mRestartOnceOnExit;
+    int mShutdownTimeout;
 };
 
 }
