@@ -18,45 +18,28 @@
  ***************************************************************************/
 #include "login.h"
 
-#include <QtCore/QDebug>
-
 #include "response.h"
-#include "../../libs/imapparser_p.h"
-#include "akonadiconnection.h"
+#include "connection.h"
+#include "imapstreamparser.h"
 
-using namespace Akonadi;
+using namespace Akonadi::Server;
 
 Login::Login(): Handler()
 {
 }
 
-
-Login::~Login()
+bool Login::parseStream()
 {
-}
-
-
-bool Login::handleLine( const QByteArray &line )
-{
-  int pos = line.indexOf( ' ' ) + 1; // skip tag
-  pos = line.indexOf( ' ', pos ); // skip command
-  if ( pos < 0 )
-    return failureResponse( "Invalid syntax" );
-
-  QByteArray sessionId;
-  pos = ImapParser::parseString( line, sessionId, pos );
-  if ( sessionId.isEmpty() )
+  const QByteArray sessionId = m_streamParser->readString();
+  if ( sessionId.isEmpty() ) {
     return failureResponse( "Missing session identifier." );
+  }
   connection()->setSessionId( sessionId );
 
-  Response response;
-  response.setTag( tag() );
-  response.setSuccess();
-  response.setString( "User logged in" );
+  // ignore anything that follows, for Roundcube compatibility
+  m_streamParser->readUntilCommandEnd();
 
-  emit responseAvailable( response );
-  emit connectionStateChange( Authenticated );
-  deleteLater();
+  successResponse( "User logged in" );
+  Q_EMIT connectionStateChange( Authenticated );
   return true;
 }
-
