@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2006 Volker Krause <volker.krause@rwth-aachen.de>
+    Copyright (c) 2006 Volker Krause <vkrause@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -22,9 +22,8 @@
 
 #include <QtCore/QObject>
 
-#include "agentmanagerinterface.h"
-
 namespace Akonadi {
+namespace Server {
 
 /**
   Listens to agent instance added/removed signals and creates/removes
@@ -40,15 +39,16 @@ class ResourceManager : public QObject
   private:
     ResourceManager( QObject *parent = 0 );
 
-  private Q_SLOTS:
-    void resourceAdded( const QString &name );
-    void resourceRemoved( const QString &name );
+  public Q_SLOTS:
+    void addResourceInstance( const QString &name, const QStringList &capabilities );
+    void removeResourceInstance( const QString &name );
+    QStringList resourceInstances() const;
 
   private:
-    static ResourceManager* mSelf;
-    org::freedesktop::Akonadi::AgentManager *mManager;
+    static ResourceManager *mSelf;
 };
 
-}
+} // namespace Server
+} // namespace Akonadi
 
 #endif
